@@ -3,6 +3,7 @@ import asyncio
 import msgpack
 from datetime import datetime
 import uuid as uuid_pkg
+import traceback
 
 from .events import DuctConnectionEvent
 from .event_listeners import ConnectionEventListener
@@ -44,7 +45,7 @@ class Duct:
                 
 
         except Exception as e:
-            print(e)
+            print(traceback.format_exc())
             await self.connection_listener.onerror(DuctConnectionEvent("onerror", e))
     
     async def open(self, wsd_url, uuid=None, params=None):
